### Changelog

#### 1.0.1 - 30/04/2020

* Mudanças no README.md.
* Adição do CHANGELOG.md.
* Tratamento do _config_path_ quando estiver terminando com uma barra ('/').

#### 1.0.0 - 30/04/2020

* Versão inicial.
